==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicInternalFrameTitlePane__24PaneButton.h <==
// class javax.swing.plaf.basic.BasicInternalFrameTitlePane$PaneButton

// class file dependencies
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 7391d27632d03ad8 javax_swing_AbstractButton
// @dep_class 69f2be1043a99512 javax_swing_JButton
// @dep_class 6c83b58ef8abc63e javax_swing_JComponent
// @dep_class 28362821531050d javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton

// header file dependencies
// @dep_header javax_swing_JButton

#include "javax/swing/JButton.h"

#ifndef _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton_H_
#define _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_Action$object;
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$sub_refs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$refs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$object	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$vmethods	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$vtable	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$vtype	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$method$_init$1507ac252aa898e3(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$object *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$method$isFocusable$ea8079fcf8155500(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$method_info$isFocusable$ea8079fcf8155500;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$vmethods {
	jboolean	(*isFocusable$ea8079fcf8155500)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_AbstractButton$vmethods	javax_swing_AbstractButton;
	_jc_javax_swing_JButton$vmethods	javax_swing_JButton;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$vmethods	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$refs {
    _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$sub_refs	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton;
    _jc_javax_swing_JButton$sub_refs	javax_swing_JButton;
    _jc_javax_swing_AbstractButton$sub_refs	javax_swing_AbstractButton;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_AbstractButton$sub_nonrefs	javax_swing_AbstractButton;
    _jc_javax_swing_JButton$sub_nonrefs	javax_swing_JButton;
    _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$sub_nonrefs	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$object {
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$vtype _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicInternalFrameTitlePane__24PaneButton.h <==
// class javax.swing.plaf.basic.BasicInternalFrameTitlePane$PaneButton

// class file dependencies
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7391d27632d03ad8 javax_swing_AbstractButton
// @dep_class 69f2be1043a99512 javax_swing_JButton
// @dep_class c84352ee73c7cec1 javax_swing_JComponent
// @dep_class 28362821531050d javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton

// header file dependencies
// @dep_header javax_swing_JButton

#include "javax/swing/JButton.h"

#ifndef _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton_H_
#define _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_Action$object;
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$sub_refs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$refs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$object	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$vmethods	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$vtable	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$vtype	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$method$_init$1507ac252aa898e3(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$object *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$method$isFocusable$ea8079fcf8155500(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$method_info$isFocusable$ea8079fcf8155500;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$vmethods {
	jboolean	(*isFocusable$ea8079fcf8155500)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_AbstractButton$vmethods	javax_swing_AbstractButton;
	_jc_javax_swing_JButton$vmethods	javax_swing_JButton;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$vmethods	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$refs {
    _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$sub_refs	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton;
    _jc_javax_swing_JButton$sub_refs	javax_swing_JButton;
    _jc_javax_swing_AbstractButton$sub_refs	javax_swing_AbstractButton;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_AbstractButton$sub_nonrefs	javax_swing_AbstractButton;
    _jc_javax_swing_JButton$sub_nonrefs	javax_swing_JButton;
    _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$sub_nonrefs	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$object {
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$vtype _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24PaneButton_H_ */
